@@ -8,8 +8,8 @@ _HELP_MESSAGE_REUSE = """
     FOSSLight Reuse is a Tool to check REUSE compliance in source code.
 
     Usage: fosslight_reuse [Mode] [option1] <arg1> [option2] <arg2>...
-     ex) fosslight_reuse lint -p /home/test/ -f "notice/sample.py,src/init.py"
-         fosslight_reuse add -p /home/test/ -c "2019-2021 LG Electronics Inc." -l "GPL-3.0-only"
+     ex) fosslight_reuse lint -p /home/test/src/
+         fosslight_reuse add -p /home/test/test.py -c "2019-2021 LG Electronics Inc." -l "GPL-3.0-only"
 
     Parameters:
         Mode
@@ -20,12 +20,17 @@ _HELP_MESSAGE_REUSE = """
         Options:
             -h\t\t\t    Print help message
             -p <path>\t\t    Path to check
-            -f <file1,file2,..>\t    List of files to check
+            -f <format>\t\t    Result format(yaml, xml, html)
             -o <file_name>\t    Output file name
             -n\t\t\t    Don't exclude venv*, node_modules, and .*/ from the analysis
+            -i\t\t\t    Don't write log to file
+
         Options for only 'add' mode
             -l <license>\t    License name(SPDX format) to add
-            -c <copyright>\t    Copyright to add(ex, 2015-2021 LG Electronics Inc.)"""
+            -c <copyright>\t    Copyright to add(ex, 2015-2021 LG Electronics Inc.)
+
+        Options for only 'convert' mode
+            -s <sheet_names>\t    Sheet name in excel to change to yaml(ex. SRC,BIN)"""
 
 
 def print_help_msg(exitOpt=True):
